package atom

import (
	"encoding/xml"
	"fmt"
)

type CommonAttributes struct {
	Base                string      `xml:"base,attr,omitempty"` // IRI
	Lang                string      `xml:"lang,attr,omitempty"` // LanguageTag
	UndefinedAttributes []*xml.Attr `xml:",attr,omitempty"`
}

// NewCommonAttributes creates a new set of CommonAttributes. It returns a
// *CommonAttributes.
func newCommonAttributes() *CommonAttributes {
	return new(CommonAttributes)
}

// AddAttribute adds the Attribute to the CommonAttributes.
func (c *CommonAttributes) AddAttribute(name, value string) {
	if c.UndefinedAttributes == nil {
		c.UndefinedAttributes = make([]*xml.Attr, 1)
		c.UndefinedAttributes[0] = &xml.Attr{Name: xml.Name{Local: name}, Value: value}
	} else {
		c.UndefinedAttributes = append(c.UndefinedAttributes, &xml.Attr{Name: xml.Name{Local: name}, Value: value})
	}
}

// Check checks the CommonAttributes for incompatibilities with RFC4287. It
// returns an error.
func (c *CommonAttributes) Check() error {
	for i, u := range c.UndefinedAttributes {
		if u.Name.Local == "" {
			return fmt.Errorf("xml name of undefined attribute %v empty", i)
		}
		if u.Value == "" {
			return fmt.Errorf("value of undefined attribute %v empty", i)
		}
	}

	return nil
}
